pub struct ToolRegistry { /* private fields */ }Expand description
A thread-safe registry that maps tool names to their implementations.
Implementations
Sourceimpl ToolRegistry
impl ToolRegistry
Sourcepub fn register<T: Tool + 'static>(&self, tool: T)
pub fn register<T: Tool + 'static>(&self, tool: T)
Register a tool. Overwrites any previously registered tool with the same name.
Sourcepub fn register_arc(&self, tool: Arc<dyn Tool>)
pub fn register_arc(&self, tool: Arc<dyn Tool>)
Register a tool that is already boxed as Arc<dyn Tool>.
Sourcepub fn tool_names(&self) -> Vec<String>
pub fn tool_names(&self) -> Vec<String>
Return all registered tool names.
Sourcepub fn tool_definitions(&self) -> Vec<ToolDefinition>
pub fn tool_definitions(&self) -> Vec<ToolDefinition>
Build a list of ToolDefinition for every registered tool.
Sourcepub async fn execute(&self, name: &str, args: Value) -> Result<ToolResult>
pub async fn execute(&self, name: &str, args: Value) -> Result<ToolResult>
Convenience: execute a tool by name with the given JSON args.
Sourcepub fn register_list_tools(&self)
pub fn register_list_tools(&self)
Create a ListToolsTool that references this registry and register it.