Built-in tools: echo, list_tools, read_file, write_file, ask_user.
Structs
- AskUser
Tool - Signals that the agent needs to ask the user a question.
- Echo
Tool - A simple echo tool useful for testing.
- List
Tools Tool - Lists all registered tools and their descriptions.
- Read
File Tool - Reads a file from disk and returns its contents.
- Write
File Tool - Writes content to a file on disk.